@@ -13,6 +13,21 @@ Q_IMPORT_PLUGIN (QWindowsIntegrationPlugin);
 
 int ui_main(int argc, char **argv)
 {
+
+#ifdef Q_OS_WIN
+	// Enables automatic high-DPI scaling
+	// https://github.com/equalsraf/neovim-qt/issues/391
+	//
+	// The other way to do this is to set Qt::AA_EnableHighDpiScaling
+	// but it does not seem to work on Windows.
+	//
+	// @equalsraf: For now I'm setting this in windows only, there open
+	// issues in upstream Qt that suggests this may have unexpected effects
+	// in other systems (QTBUG-65061, QTBUG-65102), also QTBUG-63580 offers
+	// contradictory information with what we have experienced.
+	qputenv("QT_AUTO_SCREEN_SCALE_FACTOR", "1");
+#endif
+
 	NeovimQt::App app(argc, argv);
 
 	QCommandLineParser parser;
@@ -53,6 +68,10 @@ int main(int argc, char **argv)
 			break;
 		} else if (QString::compare("--spawn", argv[i]) == 0) {
 			break;
+		} else if (QString::compare("--embed", argv[i]) == 0) {
+			// Due to https://github.com/equalsraf/neovim-qt/issues/276 --embed
+			// implies --nofork
+			nofork = true;
 		} else if (QString::compare("--nofork", argv[i]) == 0) {
 			nofork = true;
 		}
