@@ -26,7 +26,8 @@ NeovimConnector::NeovimConnector(QIODevice *dev)
 
 NeovimConnector::NeovimConnector(MsgpackIODevice *dev)
 :QObject(), m_dev(dev), m_helper(0), m_error(NoError), m_api0(NULL), m_api1(NULL), m_api2(NULL), m_api3(NULL),
-	m_channel(0), m_api_compat(0), m_api_supported(0), m_ctype(OtherConnection), m_ready(false), m_timeout(20000)
+	m_api4(NULL), m_channel(0), m_api_compat(0), m_api_supported(0), m_ctype(OtherConnection), m_ready(false),
+	m_timeout(20000)
 {
 	m_helper = new NeovimConnectorHelper(this);
 	qRegisterMetaType<NeovimError>("NeovimError");
@@ -145,7 +146,7 @@ NeovimApi0* NeovimConnector::api0()
 		if (m_api_compat <= 0) {
 			m_api0 = new NeovimApi0(this);
 		} else {
-			qDebug() << "This instance of neovim DOES NOT not support api level 0";
+			qDebug() << "This instance of neovim DOES NOT support api level 0";
 		}
 	}
 	return m_api0;
@@ -160,7 +161,7 @@ NeovimApi1* NeovimConnector::api1()
 		if (m_api_compat <= 1 && 1 <= m_api_supported) {
 			m_api1 = new NeovimApi1(this);
 		} else {
-			qDebug() << "This instance of neovim DOES NOT not support api level 1";
+			qDebug() << "This instance of neovim DOES NOT support api level 1";
 		}
 	}
 	return m_api1;
@@ -204,6 +205,22 @@ NeovimApi3* NeovimConnector::api3()
 	return m_api3;
 }
 
+/**
+ * @warning Do not call this before NeovimConnector::ready as been signaled
+ * @see NeovimConnector::isReady
+ */
+NeovimApi4* NeovimConnector::api4()
+{
+	if ( !m_api4 ) {
+		if (m_api_compat <= 4 && 4 <= m_api_supported) {
+			m_api4 = new NeovimApi4(this);
+		} else {
+			qWarning() << "This instance of neovim not support api level 4";
+		}
+	}
+	return m_api4;
+}
+
 /**
  * Launch an embedded Neovim process
  * @see processExited
@@ -215,12 +232,12 @@ NeovimConnector* NeovimConnector::spawn(const QStringList& params, const QString
 	// Neovim accepts a `--' argument after which only filenames are passed.
 	// If the user has supplied it, our arguments must appear before.
 	if (params.indexOf("--") == -1) {
-		args << "--embed" << "--headless";
+		args << "--embed";
 		args.append(params);
 	} else {
 		int idx = params.indexOf("--");
 		args.append(params.mid(0, idx));
-		args << "--embed" << "--headless";
+		args << "--embed";
 		args.append(params.mid(idx));
 	}
 
@@ -364,6 +381,11 @@ void NeovimConnector::fatalTimeout()
 	setError(RuntimeMsgpackError, "Neovim is taking too long to respond");
 }
 
+void NeovimConnector::setRequestHandler(MsgpackRequestHandler *h)
+{
+	m_dev->setRequestHandler(h);
+}
+
 /**
  * True if NeovimConnector::reconnect can be called to reconnect with Neovim. This
  * is true unless you built the NeovimConnector ctor directly instead
